summaryrefslogtreecommitdiffstatshomepage
path: root/src/mame/audio/svis_snd.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/mame/audio/svis_snd.cpp')
-rw-r--r--src/mame/audio/svis_snd.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/mame/audio/svis_snd.cpp b/src/mame/audio/svis_snd.cpp
index a51dbb15d35..91fdd2dcce1 100644
--- a/src/mame/audio/svis_snd.cpp
+++ b/src/mame/audio/svis_snd.cpp
@@ -45,15 +45,15 @@ void svision_sound_device::device_start()
memset(&m_noise, 0, sizeof(m_noise));
memset(m_channel, 0, sizeof(m_channel));
- m_mixer_channel = stream_alloc(0, 2, machine().sample_rate());
+ m_mixer_channel = stream_alloc_legacy(0, 2, machine().sample_rate());
}
//-------------------------------------------------
// sound_stream_update - handle a stream update
//-------------------------------------------------
-void svision_sound_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void svision_sound_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
stream_sample_t *left=outputs[0], *right=outputs[1];
@@ -45,15 +45,15 @@ void svision_sound_device::device_start()
}
//-------------------------------------------------
-// sound_stream_update - handle a stream update
+// sound_stream_update_legacy - handle a stream update
//-------------------------------------------------